==> kubernetes-model-gatewayapi-6.6.2-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1beta1/ReferenceGrantSpecFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface ReferenceGrantSpecFluent<A extends ReferenceGrantSpecFluent<A>> extends Fluent<A>{
  public A addToFrom(Integer index,ReferenceGrantFrom item);
  public A setToFrom(Integer index,ReferenceGrantFrom item);
  public A addToFrom(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.ReferenceGrantFrom... items);
  public A addAllToFrom(Collection<ReferenceGrantFrom> items);
  public A removeFromFrom(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.ReferenceGrantFrom... items);
  public A removeAllFromFrom(Collection<ReferenceGrantFrom> items);
  public A removeMatchingFromFrom(Predicate<ReferenceGrantFromBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildFrom instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ReferenceGrantFrom> getFrom();
  public List<ReferenceGrantFrom> buildFrom();
  public ReferenceGrantFrom buildFrom(Integer index);
  public ReferenceGrantFrom buildFirstFrom();
  public ReferenceGrantFrom buildLastFrom();
  public ReferenceGrantFrom buildMatchingFrom(Predicate<ReferenceGrantFromBuilder> predicate);
  public Boolean hasMatchingFrom(Predicate<ReferenceGrantFromBuilder> predicate);
  public A withFrom(List<ReferenceGrantFrom> from);
  public A withFrom(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.ReferenceGrantFrom... from);
  public Boolean hasFrom();
  public A addNewFrom(String group,String kind,String namespace);
  public ReferenceGrantSpecFluent.FromNested<A> addNewFrom();
  public ReferenceGrantSpecFluent.FromNested<A> addNewFromLike(ReferenceGrantFrom item);
  public ReferenceGrantSpecFluent.FromNested<A> setNewFromLike(Integer index,ReferenceGrantFrom item);
  public ReferenceGrantSpecFluent.FromNested<A> editFrom(Integer index);
  public ReferenceGrantSpecFluent.FromNested<A> editFirstFrom();
  public ReferenceGrantSpecFluent.FromNested<A> editLastFrom();
  public ReferenceGrantSpecFluent.FromNested<A> editMatchingFrom(Predicate<ReferenceGrantFromBuilder> predicate);
  public A addToTo(Integer index,ReferenceGrantTo item);
  public A setToTo(Integer index,ReferenceGrantTo item);
  public A addToTo(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.ReferenceGrantTo... items);
  public A addAllToTo(Collection<ReferenceGrantTo> items);
  public A removeFromTo(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.ReferenceGrantTo... items);
  public A removeAllFromTo(Collection<ReferenceGrantTo> items);
  public A removeMatchingFromTo(Predicate<ReferenceGrantToBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildTo instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ReferenceGrantTo> getTo();
  public List<ReferenceGrantTo> buildTo();
  public ReferenceGrantTo buildTo(Integer index);
  public ReferenceGrantTo buildFirstTo();
  public ReferenceGrantTo buildLastTo();
  public ReferenceGrantTo buildMatchingTo(Predicate<ReferenceGrantToBuilder> predicate);
  public Boolean hasMatchingTo(Predicate<ReferenceGrantToBuilder> predicate);
  public A withTo(List<ReferenceGrantTo> to);
  public A withTo(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.ReferenceGrantTo... to);
  public Boolean hasTo();
  public A addNewTo(String group,String kind,String name);
  public ReferenceGrantSpecFluent.ToNested<A> addNewTo();
  public ReferenceGrantSpecFluent.ToNested<A> addNewToLike(ReferenceGrantTo item);
  public ReferenceGrantSpecFluent.ToNested<A> setNewToLike(Integer index,ReferenceGrantTo item);
  public ReferenceGrantSpecFluent.ToNested<A> editTo(Integer index);
  public ReferenceGrantSpecFluent.ToNested<A> editFirstTo();
  public ReferenceGrantSpecFluent.ToNested<A> editLastTo();
  public ReferenceGrantSpecFluent.ToNested<A> editMatchingTo(Predicate<ReferenceGrantToBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface FromNested<N> extends Nested<N>,ReferenceGrantFromFluent<ReferenceGrantSpecFluent.FromNested<N>>{
    public N and();
    public N endFrom();
    
  }
  public interface ToNested<N> extends Nested<N>,ReferenceGrantToFluent<ReferenceGrantSpecFluent.ToNested<N>>{
    public N and();
    public N endTo();
    
  }
  
}

==> kubernetes-model-gatewayapi-6.7.0-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1beta1/ReferenceGrantSpecFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public interface ReferenceGrantSpecFluent<A extends ReferenceGrantSpecFluent<A>> extends Fluent<A>{
  public A addToFrom(int index,ReferenceGrantFrom item);
  public A setToFrom(int index,ReferenceGrantFrom item);
  public A addToFrom(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.ReferenceGrantFrom... items);
  public A addAllToFrom(Collection<ReferenceGrantFrom> items);
  public A removeFromFrom(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.ReferenceGrantFrom... items);
  public A removeAllFromFrom(Collection<ReferenceGrantFrom> items);
  public A removeMatchingFromFrom(Predicate<ReferenceGrantFromBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildFrom instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ReferenceGrantFrom> getFrom();
  public List<ReferenceGrantFrom> buildFrom();
  public ReferenceGrantFrom buildFrom(int index);
  public ReferenceGrantFrom buildFirstFrom();
  public ReferenceGrantFrom buildLastFrom();
  public ReferenceGrantFrom buildMatchingFrom(Predicate<ReferenceGrantFromBuilder> predicate);
  public Boolean hasMatchingFrom(Predicate<ReferenceGrantFromBuilder> predicate);
  public A withFrom(List<ReferenceGrantFrom> from);
  public A withFrom(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.ReferenceGrantFrom... from);
  public Boolean hasFrom();
  public A addNewFrom(String group,String kind,String namespace);
  public ReferenceGrantSpecFluent.FromNested<A> addNewFrom();
  public ReferenceGrantSpecFluent.FromNested<A> addNewFromLike(ReferenceGrantFrom item);
  public ReferenceGrantSpecFluent.FromNested<A> setNewFromLike(int index,ReferenceGrantFrom item);
  public ReferenceGrantSpecFluent.FromNested<A> editFrom(int index);
  public ReferenceGrantSpecFluent.FromNested<A> editFirstFrom();
  public ReferenceGrantSpecFluent.FromNested<A> editLastFrom();
  public ReferenceGrantSpecFluent.FromNested<A> editMatchingFrom(Predicate<ReferenceGrantFromBuilder> predicate);
  public A addToTo(int index,ReferenceGrantTo item);
  public A setToTo(int index,ReferenceGrantTo item);
  public A addToTo(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.ReferenceGrantTo... items);
  public A addAllToTo(Collection<ReferenceGrantTo> items);
  public A removeFromTo(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.ReferenceGrantTo... items);
  public A removeAllFromTo(Collection<ReferenceGrantTo> items);
  public A removeMatchingFromTo(Predicate<ReferenceGrantToBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildTo instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<ReferenceGrantTo> getTo();
  public List<ReferenceGrantTo> buildTo();
  public ReferenceGrantTo buildTo(int index);
  public ReferenceGrantTo buildFirstTo();
  public ReferenceGrantTo buildLastTo();
  public ReferenceGrantTo buildMatchingTo(Predicate<ReferenceGrantToBuilder> predicate);
  public Boolean hasMatchingTo(Predicate<ReferenceGrantToBuilder> predicate);
  public A withTo(List<ReferenceGrantTo> to);
  public A withTo(io.fabric8.kubernetes.api.model.gatewayapi.v1beta1.ReferenceGrantTo... to);
  public Boolean hasTo();
  public A addNewTo(String group,String kind,String name);
  public ReferenceGrantSpecFluent.ToNested<A> addNewTo();
  public ReferenceGrantSpecFluent.ToNested<A> addNewToLike(ReferenceGrantTo item);
  public ReferenceGrantSpecFluent.ToNested<A> setNewToLike(int index,ReferenceGrantTo item);
  public ReferenceGrantSpecFluent.ToNested<A> editTo(int index);
  public ReferenceGrantSpecFluent.ToNested<A> editFirstTo();
  public ReferenceGrantSpecFluent.ToNested<A> editLastTo();
  public ReferenceGrantSpecFluent.ToNested<A> editMatchingTo(Predicate<ReferenceGrantToBuilder> predicate);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface FromNested<N> extends Nested<N>,ReferenceGrantFromFluent<ReferenceGrantSpecFluent.FromNested<N>>{
    public N and();
    public N endFrom();
    
  }
  public interface ToNested<N> extends Nested<N>,ReferenceGrantToFluent<ReferenceGrantSpecFluent.ToNested<N>>{
    public N and();
    public N endTo();
    
  }
  
}
